Reviewers: Vitaly Repeshko,

Description:
Remove `sfi' abbreviations (a follow-up to r6902).

BUG=none
TEST=none

Please review this at http://codereview.chromium.org/6646022/

SVN Base: https://v8.googlecode.com/svn/branches/bleeding_edge

Affected files:
  M src/cpu-profiler-inl.h
  M src/cpu-profiler.h
  M src/cpu-profiler.cc
  M src/heap.cc
  M src/log.h
  M src/log.cc
  M src/mark-compact.cc
  M src/profile-generator.h
  M src/profile-generator.cc


Index: src/cpu-profiler-inl.h
diff --git a/src/cpu-profiler-inl.h b/src/cpu-profiler-inl.h
index 440dedca6e760dd8954adad6fa6dae9403c40665..eb0f9cb4f0008ddd38d98945d85c5110a976f136 100644
--- a/src/cpu-profiler-inl.h
+++ b/src/cpu-profiler-inl.h
@@ -41,8 +41,8 @@ namespace internal {

 void CodeCreateEventRecord::UpdateCodeMap(CodeMap* code_map) {
   code_map->AddCode(start, entry, size);
-  if (sfi_address != NULL) {
-    entry->set_shared_id(code_map->GetSFITag(sfi_address));
+  if (shared != NULL) {
+    entry->set_shared_id(code_map->GetSharedId(shared));
   }
 }

@@ -57,7 +57,7 @@ void CodeDeleteEventRecord::UpdateCodeMap(CodeMap* code_map) {
 }


-void SFIMoveEventRecord::UpdateCodeMap(CodeMap* code_map) {
+void SharedFunctionMoveEventRecord::UpdateCodeMap(CodeMap* code_map) {
   code_map->MoveCode(from, to);
 }

Index: src/cpu-profiler.cc
diff --git a/src/cpu-profiler.cc b/src/cpu-profiler.cc
index ad04a003b2c591704d23de745e3946439a8463e3..29b01182ed939d2e3606a6f57bcb1e515f01e4c5 100644
--- a/src/cpu-profiler.cc
+++ b/src/cpu-profiler.cc
@@ -69,7 +69,7 @@ void ProfilerEventsProcessor::CallbackCreateEvent(Logger::LogEventsAndTags tag,
   rec->start = start;
   rec->entry = generator_->NewCodeEntry(tag, prefix, name);
   rec->size = 1;
-  rec->sfi_address = NULL;
+  rec->shared = NULL;
   events_buffer_.Enqueue(evt_rec);
 }

@@ -80,7 +80,7 @@ void ProfilerEventsProcessor::CodeCreateEvent(Logger::LogEventsAndTags tag,
                                               int line_number,
                                               Address start,
                                               unsigned size,
-                                              Address sfi_address) {
+                                              Address shared) {
   if (FilterOutCodeCreateEvent(tag)) return;
   CodeEventsContainer evt_rec;
   CodeCreateEventRecord* rec = &evt_rec.CodeCreateEventRecord_;
@@ -89,7 +89,7 @@ void ProfilerEventsProcessor::CodeCreateEvent(Logger::LogEventsAndTags tag,
   rec->start = start;
rec->entry = generator_->NewCodeEntry(tag, name, resource_name, line_number);
   rec->size = size;
-  rec->sfi_address = sfi_address;
+  rec->shared = shared;
   events_buffer_.Enqueue(evt_rec);
 }

@@ -106,7 +106,7 @@ void ProfilerEventsProcessor::CodeCreateEvent(Logger::LogEventsAndTags tag,
   rec->start = start;
   rec->entry = generator_->NewCodeEntry(tag, name);
   rec->size = size;
-  rec->sfi_address = NULL;
+  rec->shared = NULL;
   events_buffer_.Enqueue(evt_rec);
 }

@@ -123,7 +123,7 @@ void ProfilerEventsProcessor::CodeCreateEvent(Logger::LogEventsAndTags tag,
   rec->start = start;
   rec->entry = generator_->NewCodeEntry(tag, args_count);
   rec->size = size;
-  rec->sfi_address = NULL;
+  rec->shared = NULL;
   events_buffer_.Enqueue(evt_rec);
 }

@@ -149,10 +149,10 @@ void ProfilerEventsProcessor::CodeDeleteEvent(Address from) {
 }


-void ProfilerEventsProcessor::SFIMoveEvent(Address from, Address to) {
+void ProfilerEventsProcessor::SharedFunctionMoveEvent(Address from, Address to) {
   CodeEventsContainer evt_rec;
-  SFIMoveEventRecord* rec = &evt_rec.SFIMoveEventRecord_;
-  rec->type = CodeEventRecord::SFI_MOVE;
+ SharedFunctionMoveEventRecord* rec = &evt_rec.SharedFunctionMoveEventRecord_;
+  rec->type = CodeEventRecord::SHARED_FUNC_MOVE;
   rec->order = ++enqueue_order_;
   rec->from = from;
   rec->to = to;
@@ -403,8 +403,8 @@ void CpuProfiler::CodeDeleteEvent(Address from) {
 }


-void CpuProfiler::SFIMoveEvent(Address from, Address to) {
-  singleton_->processor_->SFIMoveEvent(from, to);
+void CpuProfiler::SharedFunctionMoveEvent(Address from, Address to) {
+  singleton_->processor_->SharedFunctionMoveEvent(from, to);
 }


Index: src/cpu-profiler.h
diff --git a/src/cpu-profiler.h b/src/cpu-profiler.h
index 1ebbfebf74cb3bf43eb83c838ed65d215c32cfc6..db5bfb15d31f8e5a366070324038509ff6436f72 100644
--- a/src/cpu-profiler.h
+++ b/src/cpu-profiler.h
@@ -46,11 +46,11 @@ class HashMap;
 class ProfileGenerator;
 class TokenEnumerator;

-#define CODE_EVENTS_TYPE_LIST(V)                \
-  V(CODE_CREATION, CodeCreateEventRecord)       \
-  V(CODE_MOVE,     CodeMoveEventRecord)         \
-  V(CODE_DELETE,   CodeDeleteEventRecord)       \
-  V(SFI_MOVE,      SFIMoveEventRecord)
+#define CODE_EVENTS_TYPE_LIST(V)                                \
+  V(CODE_CREATION, CodeCreateEventRecord)                       \
+  V(CODE_MOVE,     CodeMoveEventRecord)                         \
+  V(CODE_DELETE,   CodeDeleteEventRecord)                       \
+  V(SHARED_FUNC_MOVE,      SharedFunctionMoveEventRecord)


 class CodeEventRecord {
@@ -73,7 +73,7 @@ class CodeCreateEventRecord : public CodeEventRecord {
   Address start;
   CodeEntry* entry;
   unsigned size;
-  Address sfi_address;
+  Address shared;

   INLINE(void UpdateCodeMap(CodeMap* code_map));
 };
@@ -96,7 +96,7 @@ class CodeDeleteEventRecord : public CodeEventRecord {
 };


-class SFIMoveEventRecord : public CodeEventRecord {
+class SharedFunctionMoveEventRecord : public CodeEventRecord {
  public:
   Address from;
   Address to;
@@ -149,7 +149,7 @@ class ProfilerEventsProcessor : public Thread {
                        String* name,
                        String* resource_name, int line_number,
                        Address start, unsigned size,
-                       Address sfi_address);
+                       Address shared);
   void CodeCreateEvent(Logger::LogEventsAndTags tag,
                        const char* name,
                        Address start, unsigned size);
@@ -158,7 +158,7 @@ class ProfilerEventsProcessor : public Thread {
                        Address start, unsigned size);
   void CodeMoveEvent(Address from, Address to);
   void CodeDeleteEvent(Address from);
-  void SFIMoveEvent(Address from, Address to);
+  void SharedFunctionMoveEvent(Address from, Address to);
   void RegExpCodeCreateEvent(Logger::LogEventsAndTags tag,
                              const char* prefix, String* name,
                              Address start, unsigned size);
@@ -251,7 +251,7 @@ class CpuProfiler {
   static void GetterCallbackEvent(String* name, Address entry_point);
   static void RegExpCodeCreateEvent(Code* code, String* source);
   static void SetterCallbackEvent(String* name, Address entry_point);
-  static void SFIMoveEvent(Address from, Address to);
+  static void SharedFunctionMoveEvent(Address from, Address to);

   static INLINE(bool is_profiling()) {
     return NoBarrier_Load(&is_profiling_);
Index: src/heap.cc
diff --git a/src/heap.cc b/src/heap.cc
index 199ee60116785961ef38067c611c1e86eafd057f..3d6352960100a8d1eb03b37b4b970748b8aa7a6f 100644
--- a/src/heap.cc
+++ b/src/heap.cc
@@ -1341,7 +1341,7 @@ class ScavengingVisitor : public StaticVisitorBase {
 #if defined(ENABLE_LOGGING_AND_PROFILING)
     if (Logger::is_logging() || CpuProfiler::is_profiling()) {
       if (target->IsSharedFunctionInfo()) {
-        PROFILE(SFIMoveEvent(source->address(), target->address()));
+ PROFILE(SharedFunctionMoveEvent(source->address(), target->address()));
       }
     }
 #endif
Index: src/log.cc
diff --git a/src/log.cc b/src/log.cc
index bfef64300f5a4b51a18eb41e8df1349517e23547..a13ccea0144b8a985c3127ab46f6c78a8ff83cea 100644
--- a/src/log.cc
+++ b/src/log.cc
@@ -881,9 +881,9 @@ void Logger::SnapshotPositionEvent(Address addr, int pos) {
 }


-void Logger::SFIMoveEvent(Address from, Address to) {
+void Logger::SharedFunctionMoveEvent(Address from, Address to) {
 #ifdef ENABLE_LOGGING_AND_PROFILING
-  MoveEventInternal(SFI_MOVE_EVENT, from, to);
+  MoveEventInternal(SHARED_FUNC_MOVE_EVENT, from, to);
 #endif
 }

Index: src/log.h
diff --git a/src/log.h b/src/log.h
index 5470fd683bfea3b882495839a4438f0c21efe058..448399903444799870cb32e0c96d3a720e369f39 100644
--- a/src/log.h
+++ b/src/log.h
@@ -91,7 +91,7 @@ class LogMessageBuilder;
   V(CODE_MOVE_EVENT,                "code-move")                \
   V(CODE_DELETE_EVENT,              "code-delete")              \
   V(CODE_MOVING_GC,                 "code-moving-gc")           \
-  V(SFI_MOVE_EVENT,                 "sfi-move")                 \
+  V(SHARED_FUNC_MOVE_EVENT,         "sfi-move")                 \
   V(SNAPSHOT_POSITION_EVENT,        "snapshot-pos")             \
   V(TICK_EVENT,                     "tick")                     \
   V(REPEAT_META_EVENT,              "repeat")                   \
@@ -224,7 +224,7 @@ class Logger {
   // Emits a code delete event.
   static void CodeDeleteEvent(Address from);

-  static void SFIMoveEvent(Address from, Address to);
+  static void SharedFunctionMoveEvent(Address from, Address to);

   static void SnapshotPositionEvent(Address addr, int pos);

Index: src/mark-compact.cc
diff --git a/src/mark-compact.cc b/src/mark-compact.cc
index a4c782c59ea9f39f681b2064a2c7867d999d94ed..a90a45259439262b4d038d6f9c084aff9cd21ae7 100644
--- a/src/mark-compact.cc
+++ b/src/mark-compact.cc
@@ -2827,7 +2827,7 @@ int MarkCompactCollector::RelocateOldNonCodeObject(HeapObject* obj,

   HeapObject* copied_to = HeapObject::FromAddress(new_addr);
   if (copied_to->IsSharedFunctionInfo()) {
-    PROFILE(SFIMoveEvent(old_addr, new_addr));
+    PROFILE(SharedFunctionMoveEvent(old_addr, new_addr));
   }
   HEAP_PROFILE(ObjectMoveEvent(old_addr, new_addr));

@@ -2919,7 +2919,7 @@ int MarkCompactCollector::RelocateNewObject(HeapObject* obj) {

   HeapObject* copied_to = HeapObject::FromAddress(new_addr);
   if (copied_to->IsSharedFunctionInfo()) {
-    PROFILE(SFIMoveEvent(old_addr, new_addr));
+    PROFILE(SharedFunctionMoveEvent(old_addr, new_addr));
   }
   HEAP_PROFILE(ObjectMoveEvent(old_addr, new_addr));

Index: src/profile-generator.cc
diff --git a/src/profile-generator.cc b/src/profile-generator.cc
index 7612eab993ca123ab3bbe4a32022087f03050205..335120ebaa785ddf6ce65a3d895f41eeedbfb946 100644
--- a/src/profile-generator.cc
+++ b/src/profile-generator.cc
@@ -465,7 +465,7 @@ void CpuProfile::Print() {
 }


-CodeEntry* const CodeMap::kSfiCodeEntry = NULL;
+CodeEntry* const CodeMap::kSharedFunctionCodeEntry = NULL;
 const CodeMap::CodeTreeConfig::Key CodeMap::CodeTreeConfig::kNoKey = NULL;
 const CodeMap::CodeTreeConfig::Value CodeMap::CodeTreeConfig::kNoValue =
     CodeMap::CodeEntryInfo(NULL, 0);
@@ -483,18 +483,18 @@ CodeEntry* CodeMap::FindEntry(Address addr) {
 }


-int CodeMap::GetSFITag(Address addr) {
+int CodeMap::GetSharedId(Address addr) {
   CodeTree::Locator locator;
   // For SFI entries, 'size' field is used to store their IDs.
   if (tree_.Find(addr, &locator)) {
     const CodeEntryInfo& entry = locator.value();
-    ASSERT(entry.entry == kSfiCodeEntry);
+    ASSERT(entry.entry == kSharedFunctionCodeEntry);
     return entry.size;
   } else {
     tree_.Insert(addr, &locator);
-    int tag = next_sfi_tag_++;
-    locator.set_value(CodeEntryInfo(kSfiCodeEntry, tag));
-    return tag;
+    int id = next_shared_id_++;
+    locator.set_value(CodeEntryInfo(kSharedFunctionCodeEntry, id));
+    return id;
   }
 }
@@ -483,18 +483,18 @@ CodeEntry* CodeMap::FindEntry(Address addr) {
   CodeTree::Locator locator;
-  // For SFI entries, 'size' field is used to store their IDs.
+  // For shared function entries, 'size' field is used to store their IDs.
   if (tree_.Find(addr, &locator)) {
     const CodeEntryInfo& entry = locator.value();

Index: src/profile-generator.h
diff --git a/src/profile-generator.h b/src/profile-generator.h
index 4762eb6342b711baff7691bcf352a4026e48581a..63f65751a60f9dbca087b3afe4fcd717eb54484f 100644
--- a/src/profile-generator.h
+++ b/src/profile-generator.h
@@ -236,12 +236,12 @@ class CpuProfile {

 class CodeMap {
  public:
-  CodeMap() : next_sfi_tag_(1) { }
+  CodeMap() : next_shared_id_(1) { }
   INLINE(void AddCode(Address addr, CodeEntry* entry, unsigned size));
   INLINE(void MoveCode(Address from, Address to));
   INLINE(void DeleteCode(Address addr));
   CodeEntry* FindEntry(Address addr);
-  int GetSFITag(Address addr);
+  int GetSharedId(Address addr);

   void Print();

@@ -269,11 +269,11 @@ class CodeMap {
     void Call(const Address& key, const CodeEntryInfo& value);
   };

-  // Fake CodeEntry pointer to distinguish SFI entries.
-  static CodeEntry* const kSfiCodeEntry;
+  // Fake CodeEntry pointer to distinguish shared function entries.
+  static CodeEntry* const kSharedFunctionCodeEntry;

   CodeTree tree_;
-  int next_sfi_tag_;
+  int next_shared_id_;

   DISALLOW_COPY_AND_ASSIGN(CodeMap);
 };


--
v8-dev mailing list
[email protected]
http://groups.google.com/group/v8-dev

Reply via email to